/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.api;

import java.io.File;
import java.util.List;

import org.objectweb.easybeans.api.injection.ResourceInjector;

/**
 * Configuration for a Container.
 * @author Florent Benoit
 */
public interface EZBContainerConfig {

    /**
     * @return the callbacks
     */
    List<EZBContainerLifeCycleCallback> getCallbacks();

    /**
     * @param callback the callbacks to add.
     */
    void addCallback(final EZBContainerLifeCycleCallback callback);

    /**
     * @return the archive
     */
    File getArchive();

    /**
     * @return the injectors
     */
    List<ResourceInjector> getInjectors();

    /**
     * @param injector the injectors to set
     */
    void addInjectors(final ResourceInjector injector);

    /**
     * @return the easybeans server
     */
    EZBServer getEZBServer();

    /**
     * Sets the easybeans server.
     * @param easybeansServer the embedded server of this config
     */
    void setEZBServer(final EZBServer easybeansServer);
}
