/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JCommonBean.java 106 2006-03-03 11:02:22Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.deployment.annotations.impl;


/**
 * Defines common methods used by Session Bean and Message Driven beans.
 * @author Florent Benoit
 */
public class JCommonBean {

    /**
     * Name of the bean.
     */
    private String name = null;

    /**
     * Mapped name (could be used as JNDI name).
     */
    private String mappedName = null;

    /**
     * Description.
     */
    private String description = null;

    /**
     * Build an object that will be shared by EJB (Session + MDB).
     */
    public JCommonBean() {

    }

    /**
     * @return the description.
     */
    public String getDescription() {
        return description;
    }

    /**
     * Sets the description.
     * @param description value of description
     */
    public void setDescription(final String description) {
        this.description = description;
    }

    /**
     * @return the mapped name (JNDI ?)
     */
    public String getMappedName() {
        return mappedName;
    }

    /**
     * Sets the mapped name.
     * @param mappedName the value to set
     */
    public void setMappedName(final String mappedName) {
        this.mappedName = mappedName;
    }

    /**
     * @return name of the bean.
     */
    public String getName() {
        return name;
    }

    /**
     * Sets the bean name.
     * @param name the bean's name
     */
    public void setName(final String name) {
        this.name = name;
    }

    /**
     * @return string representation
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        // classname
        sb.append(this.getClass().getName().substring(this.getClass().getPackage().getName().length() + 1));

        // name
        sb.append("[name=");
        sb.append(name);

        // mappedName
        sb.append("[mappedName=");
        sb.append(mappedName);

        // description
        sb.append("[description=");
        sb.append(description);

        sb.append("]");
        return sb.toString();
    }
}
