/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: AbsEnvironment.java 503 2006-05-24 13:44:31Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.deployment.xml.struct.common;

import java.util.ArrayList;
import java.util.List;

import org.objectweb.easybeans.deployment.xml.struct.LifeCycleCallback;

/**
 * This class defines an implementation for an environment element.
 * @author Florent Benoit
 */
public class AbsEnvironment {

    /**
     * List of &lt;env-entry&gt; elements.
     */
    private List<EnvEntry> envEntryList = null;

    /**
     * List of &lt;post-construct&gt; elements.
     */
    private List<LifeCycleCallback> postConstructList = null;


    /**
     * List of &lt;pre-destroy&gt; elements.
     */
    private List<LifeCycleCallback> preDestroyList = null;

    /**
     * Constructor : build a new object for environment.
     */
    public AbsEnvironment() {
        envEntryList = new ArrayList<EnvEntry>();
        postConstructList = new ArrayList<LifeCycleCallback>();
        preDestroyList = new ArrayList<LifeCycleCallback>();
    }

    /**
     * Add a new env-entry element to this object.
     * @param envEntry the ejb-ref object
     */
    public void addEnvEntry(final EnvEntry envEntry) {
        envEntryList.add(envEntry);
    }

    /**
     * @return the list of all env-entry elements
     */
    public List<EnvEntry> getEnvEntryList() {
        return envEntryList;
    }

    /**
     * Add a new postConstruct element to this object.
     * @param postConstruct the post-construct object
     */
    public void addPostConstruct(final LifeCycleCallback postConstruct) {
        postConstructList.add(postConstruct);
    }

    /**
     * @return the list of all post-construct elements
     */
    public List<LifeCycleCallback> getPostConstructList() {
        return postConstructList;
    }

    /**
     * Add a new preDestroy element to this object.
     * @param preDestroy the pre-destroy object
     */
    public void addPreDestroy(final LifeCycleCallback preDestroy) {
        preDestroyList.add(preDestroy);
    }

    /**
     * @return the list of all pre-destroy elements
     */
    public List<LifeCycleCallback> getPreDestroyList() {
        return preDestroyList;
    }

}
