/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: CtxClassLoaderObjectInputStream.java 356 2006-04-18 16:26:38Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.util.marshalling;

import java.io.IOException;
import java.io.InputStream;
import java.io.ObjectInputStream;
import java.io.ObjectStreamClass;

/**
 * Reader which set the context classloader when recreating the object.
 * @author Florent Benoit
 */
public class CtxClassLoaderObjectInputStream extends ObjectInputStream {

    /**
     * This inputstream reader needs an input stream for its constructor.
     * @param inputStream input stream containing bytes
     * @throws IOException if super class fails
     */
    public CtxClassLoaderObjectInputStream(final InputStream inputStream) throws IOException {
        super(inputStream);
    }

    /**
     * Load the local class equivalent of the specified stream class
     * description.
     * @param   desc an instance of class <code>ObjectStreamClass</code>
     * @return  a <code>Class</code> object corresponding to <code>desc</code>
     * @throws  IOException any of the usual input/output exceptions
     * @throws  ClassNotFoundException if class of a serialized object cannot
     *      be found
     */
    @Override
    protected Class<?> resolveClass(final ObjectStreamClass desc)
    throws IOException, ClassNotFoundException {
        return Thread.currentThread().getContextClassLoader().loadClass(desc.getName());
    }
}
