/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: MDBInvocationOrder00.java 547 2006-05-30 13:50:43Z studzine $
 * --------------------------------------------------------------------------
 */
package org.objectweb.easybeans.tests.common.ejbs.mdb.containermanaged.interceptororder;

import static org.objectweb.easybeans.tests.common.asserts.Assert.assertEquals;
import static org.objectweb.easybeans.tests.common.ejbs.base.ItfSimpleBean.EMBEDDED_INTERCEPTOR;
import static org.objectweb.easybeans.tests.common.ejbs.entity.callbacklogger.CallbackType.AROUND_INVOKE;
import static org.objectweb.easybeans.tests.common.helper.InterceptorHelper.PROPERTY_ORDER;
import static org.objectweb.easybeans.tests.common.helper.InterceptorHelper.addValue;

import java.util.ArrayList;
import java.util.List;

import javax.ejb.ActivationConfigProperty;
import javax.ejb.MessageDriven;
import javax.interceptor.AroundInvoke;
import javax.interceptor.Interceptors;
import javax.interceptor.InvocationContext;
import javax.jms.JMSException;
import javax.jms.Message;
import javax.jms.MessageListener;

import org.objectweb.easybeans.log.JLog;
import org.objectweb.easybeans.log.JLogFactory;
import org.objectweb.easybeans.tests.common.ejbs.stateless.containermanaged.callbacklogger.BaseInsertCallbackEvent;
import org.objectweb.easybeans.tests.common.helper.InterceptorHelper;
import org.objectweb.easybeans.tests.common.interceptors.business.order.PrintOrder01Interceptor;
import org.objectweb.easybeans.tests.common.interceptors.business.order.PrintOrder02Interceptor;
import org.objectweb.easybeans.tests.common.interceptors.business.order.PrintOrder06Interceptor;
import org.objectweb.easybeans.tests.common.jms.JMSManager;

/**
 * This bean is used to test embedded interceptors.
 * @author Eduardo Studzinski Estima de Castro
 * @author Gisele Pinheiro Souza
 */
@MessageDriven(messageListenerInterface = MessageListener.class, activationConfig = {
        @ActivationConfigProperty(propertyName = "destinationType", propertyValue = "javax.jms.Queue"),
        @ActivationConfigProperty(propertyName = "destination", propertyValue = JMSManager.DEFAULT_QUEUE),
        @ActivationConfigProperty(propertyName = "messageSelector",
                propertyValue =
                    "TYPE = 'org.objectweb.easybeans.tests.common.ejbs."
                    + "mdb.containermanaged.interceptororder.MDBInvocationOrder00'")})
@Interceptors({PrintOrder01Interceptor.class})
public class MDBInvocationOrder00 extends BaseInsertCallbackEvent{

    /**
     * Logger.
     */
    private static JLog logger = JLogFactory.getLog(MDBInvocationOrder00.class);

    /**
     * Message type.
     */
    public static final String MESSAGE_TYPE =
        "org.objectweb.easybeans.tests.common.ejbs.mdb.containermanaged.interceptororder.MDBInvocationOrder00";

    /**
     * Intercepts the method and add the ORDER value in the list that was get
     * from InvocationContext. This method has private level access.
     * @param invocationContext contains attributes of invocation, the first
     *        parameter of the intercepted method must be a list.
     * @return method's invocation result
     * @throws Exception if invocation fails
     */
    @SuppressWarnings("unused")
    @AroundInvoke
    private Object addOrder(final InvocationContext invocationContext) throws Exception {
        logger.debug("Interceptor invoked.");
        return addValue(invocationContext, EMBEDDED_INTERCEPTOR, MDBInvocationOrder00.class.getName());
    }

    /**
     * Verifies the MessageDrivenContext methods.
     * @param message msg
     */
    @SuppressWarnings("unchecked")
    @Interceptors({PrintOrder02Interceptor.class, PrintOrder06Interceptor.class})
    public void onMessage(final Message message) {

        String strOrder = null;
        try {
           strOrder = message.getStringProperty(PROPERTY_ORDER);
        } catch (JMSException e) {
            e.printStackTrace();
        }

        // Checks if the property exists.
        if (strOrder == null){
            //Log
            logger.debug("There are not invoked interceptors.");
        }else{
            List<Integer> lstResult = (List<Integer>) InterceptorHelper.getArray(strOrder);

            //Log
            logger.debug("Invoked interceptors: ", lstResult);

            //Expected result
            List<Integer> lstExpected = new ArrayList<Integer>();
            lstExpected.add(PrintOrder01Interceptor.ORDER);
            lstExpected.add(PrintOrder02Interceptor.ORDER);
            lstExpected.add(PrintOrder06Interceptor.ORDER);
            lstExpected.add(EMBEDDED_INTERCEPTOR);

            assertEquals(lstExpected, lstResult, "The interceptors are not running in the correct order.");
            super.log(MDBInvocationOrder00.class, AROUND_INVOKE, MDBInvocationOrder00.class);
        }
    }
}
